@@ -5,6 +5,7 @@ from glob import glob
 from typing import Any, Dict, List, Optional, Union
 
 import numpy as np
+import pyarrow as pa
 import vaex
 from vaex.dataframe import DataFrame
 
@@ -13,8 +14,13 @@ from dataquality.core._config import config
 from dataquality.loggers.base_logger import BaseGalileoLogger, BaseLoggerAttributes
 from dataquality.schemas.split import Split
 from dataquality.utils import tqdm
+from dataquality.utils.hdf5_store import HDF5_STORE
 from dataquality.utils.thread_pool import ThreadPoolManager
-from dataquality.utils.vaex import _join_in_out_frames, _validate_unique_ids
+from dataquality.utils.vaex import (
+    _join_in_out_frames,
+    _validate_unique_ids,
+    concat_hdf5_files,
+)
 
 DATA_FOLDERS = ["emb", "prob", "data"]
 
@@ -61,15 +67,34 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
             for epoch_dir in glob(f"{split_loc}/*"):
                 epoch = int(epoch_dir.split("/")[-1])
 
-                out_frame = vaex.open(f"{epoch_dir}/*")
+                # For all epochs that aren't the last 2 (early stopping), we only want
+                # to upload the probabilities (for DEP calculation).
+                if epoch < cls.logger_config.last_epoch - 1:
+                    prob_only = True
+                else:
+                    prob_only = False
+
+                str_cols = concat_hdf5_files(epoch_dir, prob_only)
+                out_frame = vaex.open(f"{epoch_dir}/{HDF5_STORE}")
+                # Post concat, string columns come back as bytes and need conversion
+                for col in str_cols:
+                    out_frame[col] = out_frame[col].to_arrow().cast(pa.large_string())
+                if prob_only:
+                    out_frame["epoch"] = vaex.vconstant(epoch, length=len(out_frame))
+                    out_frame["split"] = vaex.vconstant(
+                        split, length=len(out_frame), dtype="str"
+                    )
+
                 _validate_unique_ids(out_frame)
                 in_out = _join_in_out_frames(in_frame, out_frame)
 
-                prob, emb, data_df = cls.split_dataframe(in_out)
+                prob, emb, data_df = cls.split_dataframe(in_out, prob_only)
 
                 for data_folder, df_obj in tqdm(
                     zip(DATA_FOLDERS, [emb, prob, data_df]), total=3, desc=split
                 ):
+                    if prob_only and data_folder != "prob":
+                        continue
                     minio_file = (
                         f"{proj_run}/{split}/{epoch}/{data_folder}/{data_folder}.hdf5"
                     )
@@ -152,5 +177,5 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
 
     @classmethod
     @abstractmethod
-    def split_dataframe(cls, df: DataFrame) -> DataFrame:
+    def split_dataframe(cls, df: DataFrame, prob_only: bool) -> DataFrame:
         ...
