@@ -22,9 +22,11 @@ def test_good_login(*args) -> None:
 
 @mock.patch("requests.post", side_effect=mocked_failed_login_requests)
 def test_bad_login(mock_post) -> None:
+    tok = config.token
     config.token = None
     os.environ[GALILEO_AUTH_METHOD] = "email"
     os.environ["GALILEO_USERNAME"] = "user"
     os.environ["GALILEO_PASSWORD"] = "password"
     with pytest.raises(Exception):
         dataquality.login()
+    config.token = tok
