@@ -1,7 +1,7 @@
 import pytorch_lightning as pl
 import torch
 
-from dataquality.core.finish import _cleanup, _upload
+import dataquality
 from dataquality.core.integrations.lightning import DataQualityCallback
 from dataquality.core.integrations.torch import log_input_data, watch
 from dataquality.utils.thread_pool import ThreadPoolManager
@@ -14,17 +14,18 @@ from tests.utils.lightning_model import (
     torch_model,
 )
 
+dataquality.config.task_type = "text_classification"
+
 
 def test_lightning_autolog(cleanup_after_use) -> None:
     """
     Tests the lightning autolog config and that data is properly stored / logged
     """
-
     train_dataloader = torch.utils.data.DataLoader(
-        NewsgroupDataset("training"), batch_size=64, shuffle=True
+        NewsgroupDataset("training"), batch_size=NUM_RECORDS, shuffle=True
     )
     test_dataloader = torch.utils.data.DataLoader(
-        NewsgroupDataset("test"), batch_size=64, shuffle=True
+        NewsgroupDataset("test"), batch_size=NUM_RECORDS, shuffle=True
     )
     trainer = pl.Trainer(
         max_epochs=1, num_sanity_val_steps=0, callbacks=[(DataQualityCallback())]
@@ -34,19 +35,20 @@ def test_lightning_autolog(cleanup_after_use) -> None:
     trainer.test(model, test_dataloader)
     ThreadPoolManager.wait_for_threads()
     # Mock call to finish
-    _upload()
+    logger = dataquality.get_data_logger()
+    logger.upload()
     validate_uploaded_data(expected_num_records=NUM_RECORDS)
-    _cleanup()
+    logger._cleanup()
     validate_cleanup_data()
 
 
 def test_torch_autolog(cleanup_after_use) -> None:
     """Tests our watch(model) functionality for pytorch"""
     train_dataloader = torch.utils.data.DataLoader(
-        NewsgroupDataset("training"), batch_size=64, shuffle=True
+        NewsgroupDataset("training"), batch_size=NUM_RECORDS, shuffle=True
     )
     test_dataloader = torch.utils.data.DataLoader(
-        NewsgroupDataset("test"), batch_size=64, shuffle=True
+        NewsgroupDataset("test"), batch_size=NUM_RECORDS, shuffle=True
     )
     device = torch.device("cuda") if torch.cuda.is_available() else torch.device("cpu")
     torch_model.to(device)
@@ -87,7 +89,8 @@ def test_torch_autolog(cleanup_after_use) -> None:
 
     ThreadPoolManager.wait_for_threads()
     # Mock call to finish
-    _upload()
+    logger = dataquality.get_data_logger()
+    logger.upload()
     validate_uploaded_data(expected_num_records=NUM_RECORDS)
-    _cleanup()
+    logger._cleanup()
     validate_cleanup_data()
